@@ -186,6 +186,11 @@ sub do_structs {
 
     walk;
 
+    # TODO: unimplemented
+    return if
+        $perlname eq 'XCBXkb_set_behavior' or
+        $perlname eq 'XCBXkb_sym_interpret';
+
     tmpl_struct($perlname, \@fields, \%type);
 
     if ($dogetter) {
@@ -277,11 +282,11 @@ sub do_requests {
 
     on switch => sub {
         my ($elem, $attr, $ctx) = @_;
-        my $mask = 'value_mask';
+        my $mask = $parser->xml =~ m,<fieldref>(.*?)</fieldref>,m ? $1 : 'value_mask';
         my $list = $attr->{'name'};
         push @param, $mask
         # eg. ConfigureWindow already specifies the mask via <field />
-            unless ($param[-1] || '') eq $mask;
+            unless first { $_ eq $mask } @param;
 
         push @param, $list;
         push @param, '...';
@@ -362,6 +367,8 @@ sub do_replies($\%\%) {
             my $pre           = xcb_name($req->{name});
 
             if ($list->{type} eq 'void') {
+                # TODO RandR structure randr_get_provider_property_reply is not supported
+                last if $perlname eq 'randr_get_provider_property_reply';
 
                 # A byte-array. Provide it as SV.
                 print OUT "    _len = reply->value_len * (reply->format / 8);\n";
@@ -378,7 +385,7 @@ sub do_replies($\%\%) {
             print OUT "    {\n";
             print OUT "    /* Handling list part of the reply */\n";
             print OUT "    alist = newAV();\n";
-            print OUT "    $iterator iterator = $pre" . '_' . $listname . "_iterator(reply);\n";
+            print OUT "    $iterator iterator = $pre" . '_' . decamelize($listname) . "_iterator(reply);\n";
             print OUT "    for (; iterator.rem > 0; $iterator_next(&iterator)) {\n";
             print OUT "      $type *data = iterator.data;\n";
             print OUT "      inner_hash = newHV();\n";
@@ -412,7 +419,9 @@ sub do_replies($\%\%) {
 sub do_enums {
     my ($tag, $attr) = @_;
 
-    my $name = uc decamelize $attr->{name};
+    # XXX hack, to get eg. a xinerama_ prefix
+    (my $ns = $prefix) =~ s/^xcb_//;
+    my $name = uc $ns . decamelize $attr->{name};
 
     if ($tag eq 'enum') {
         on item => sub {
@@ -430,7 +439,7 @@ sub do_enums {
 
 sub generate {
     my $path = ExtUtils::PkgConfig->variable('xcb-proto', 'xcbincludedir');
-    my @xcb_xmls = qw/xproto.xml xinerama.xml/;
+    my @xcb_xmls = qw/xproto.xml xinerama.xml randr.xml xkb.xml/;
 
     -d $path or die "$path: $!\n";
 
@@ -466,6 +475,10 @@ __
     $const{_NET_WM_STATE_REMOVE} = 'newSViv(0)';
     $const{_NET_WM_STATE_TOGGLE} = 'newSViv(2)';
 
+    # Add LEAVE_NOTIFY and BUTTON_RELEASE manually, as they are missing in xml
+    $const{LEAVE_NOTIFY} = 'newSViv(XCB_LEAVE_NOTIFY)';
+    $const{BUTTON_RELEASE} = 'newSViv(XCB_BUTTON_RELEASE)';
+
     # ICCCM constants from xcb-util
     for my $const (qw(XCB_ICCCM_WM_STATE_WITHDRAWN XCB_ICCCM_WM_STATE_NORMAL XCB_ICCCM_WM_STATE_ICONIC)) {
         my ($name) = ($const =~ /XCB_(.*)/);
@@ -497,6 +510,18 @@ __
 
         do_events($xcb);
 
+        # TODO RandR typemap of mode_info_t, transform_t, monitor_info_t not implemented
+        if (index $path, "randr") {
+            my $randr_exclude = join "|", qw( randr_create_mode randr_set_monitor randr_set_crtc_transform );
+            @request = grep ! /^HV \*\s+$randr_exclude\b/, @request;
+        }
+
+        # TODO xkb typemap of XCBXkb_action not implemented
+        if (index $path, "xkb") {
+            my $xkb_exclude = join "|", qw( xkb_set_device_info );
+            @request = grep ! /^HV \*\s+$xkb_exclude\b/, @request;
+        }
+
         print OUT "MODULE = X11::XCB PACKAGE = X11::XCB\n";
         print OUT @request;
         undef @request;
